# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
from ..core.request_options import RequestOptions
from .types.get_ontology_response import GetOntologyResponse
from ..core.pydantic_utilities import parse_obj_as
from ..shared_errors.errors.bad_request import BadRequest
from ..shared_errors.types.bad_request_response import BadRequestResponse
from ..shared_errors.errors.unauthorized import Unauthorized
from ..shared_errors.types.unauthorized_response import UnauthorizedResponse
from ..shared_errors.errors.not_found import NotFound
from ..shared_errors.types.not_found_response import NotFoundResponse
from ..shared_errors.errors.method_not_allowed import MethodNotAllowed
from ..shared_errors.types.method_not_allowed_response import MethodNotAllowedResponse
from ..shared_errors.errors.rate_limit_exceeded import RateLimitExceeded
from ..shared_errors.types.rate_limit_response import RateLimitResponse
from ..shared_errors.errors.internal_server_error import InternalServerError
from ..shared_errors.types.internal_server_error_response import InternalServerErrorResponse
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..generated_types.types.attributes import Attributes
from .types.get_ontology_attributes_response import GetOntologyAttributesResponse
from ..generated_types.types.country import Country
from .types.get_ontology_countries_response import GetOntologyCountriesResponse
from ..generated_types.types.currency import Currency
from .types.get_ontology_currencies_response import GetOntologyCurrenciesResponse
from ..generated_types.types.entities import Entities
from .types.get_ontology_entity_types_response import GetOntologyEntityTypesResponse
from .types.get_ontology_enums_response import GetOntologyEnumsResponse
from .types.get_ontology_hs_codes_response import GetOntologyHsCodesResponse
from ..generated_types.types.identifier_type import IdentifierType
from .types.get_ontology_identifiers_response import GetOntologyIdentifiersResponse
from ..generated_types.types.language import Language
from .types.get_ontology_languages_response import GetOntologyLanguagesResponse
from .types.get_ontology_regions_response import GetOntologyRegionsResponse
from ..generated_types.types.relationships import Relationships
from .types.get_ontology_relationships_response import GetOntologyRelationshipsResponse
from ..generated_types.types.risk import Risk
from ..generated_types.types.risk_category import RiskCategory
from ..shared_types.types.risk_level import RiskLevel
from .types.get_ontology_risk_factors_response import GetOntologyRiskFactorsResponse
from .types.get_ontology_sources_response import GetOntologySourcesResponse
from .types.get_ontology_source_types_response import GetOntologySourceTypesResponse
from ..core.client_wrapper import AsyncClientWrapper


class OntologyClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_ontology(self, *, request_options: typing.Optional[RequestOptions] = None) -> GetOntologyResponse:
        """
        Get ontology data for all resource types.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_ontology()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyResponse,
                    parse_obj_as(
                        type_=GetOntologyResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_attributes(
        self,
        *,
        id: typing.Optional[typing.Sequence[Attributes]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyAttributesResponse:
        """
        Get attributes from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Attributes]]
            Attribute Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyAttributesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_attributes(
            id=["additional_information"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/attributes",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyAttributesResponse,
                    parse_obj_as(
                        type_=GetOntologyAttributesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_countries(
        self,
        *,
        id: typing.Optional[typing.Sequence[Country]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyCountriesResponse:
        """
        Get countries from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Country]]
            Country Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyCountriesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_countries(
            id=["USA"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/countries",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyCountriesResponse,
                    parse_obj_as(
                        type_=GetOntologyCountriesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_currencies(
        self,
        *,
        id: typing.Optional[typing.Sequence[Currency]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyCurrenciesResponse:
        """
        Get currencies from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Currency]]
            Currency Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyCurrenciesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_currencies(
            id=["USD"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/currencies",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyCurrenciesResponse,
                    parse_obj_as(
                        type_=GetOntologyCurrenciesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_entity_types(
        self,
        *,
        id: typing.Optional[typing.Sequence[Entities]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyEntityTypesResponse:
        """
        Get entity types from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Entities]]
            Entity type Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyEntityTypesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_entity_types(
            id=["aircraft"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/entity_types",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyEntityTypesResponse,
                    parse_obj_as(
                        type_=GetOntologyEntityTypesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_enums(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyEnumsResponse:
        """
        Get enums from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Enum Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyEnumsResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_enums(
            id=["address_type"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/enums",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyEnumsResponse,
                    parse_obj_as(
                        type_=GetOntologyEnumsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_hs_codes(
        self,
        *,
        code: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyHsCodesResponse:
        """
        Get HS codes from ontology data.

        Parameters
        ----------
        code : typing.Optional[typing.Sequence[str]]
            HS code filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyHsCodesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_hs_codes(
            code=["1503"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/hs_codes",
            method="GET",
            params={
                "code": code,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyHsCodesResponse,
                    parse_obj_as(
                        type_=GetOntologyHsCodesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_identifiers(
        self,
        *,
        id: typing.Optional[typing.Sequence[IdentifierType]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyIdentifiersResponse:
        """
        Get identifiers from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[IdentifierType]]
            Identifier Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyIdentifiersResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_identifiers(
            id=["aer_free_zone_license"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/identifiers",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyIdentifiersResponse,
                    parse_obj_as(
                        type_=GetOntologyIdentifiersResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_languages(
        self,
        *,
        id: typing.Optional[typing.Sequence[Language]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyLanguagesResponse:
        """
        Get languages from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Language]]
            Language Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyLanguagesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_languages(
            id=["en"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/languages",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyLanguagesResponse,
                    parse_obj_as(
                        type_=GetOntologyLanguagesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_regions(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyRegionsResponse:
        """
        Get regions from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Region Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyRegionsResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_regions(
            id=["usa_&_canada"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/regions",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyRegionsResponse,
                    parse_obj_as(
                        type_=GetOntologyRegionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_relationships(
        self,
        *,
        id: typing.Optional[typing.Sequence[Relationships]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyRelationshipsResponse:
        """
        Get relationships from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Relationships]]
            Relationship Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyRelationshipsResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_relationships(
            id=["auditor_of"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/relationships",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyRelationshipsResponse,
                    parse_obj_as(
                        type_=GetOntologyRelationshipsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_risk_factors(
        self,
        *,
        id: typing.Optional[typing.Sequence[Risk]] = None,
        risk_category: typing.Optional[typing.Sequence[RiskCategory]] = None,
        level: typing.Optional[typing.Sequence[RiskLevel]] = None,
        risk_type: typing.Optional[typing.Sequence[str]] = None,
        enabled: typing.Optional[bool] = None,
        visible: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyRiskFactorsResponse:
        """
        Get risk factors from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Risk]]
            Risk factor Id filter.

        risk_category : typing.Optional[typing.Sequence[RiskCategory]]
            Risk category filter.

        level : typing.Optional[typing.Sequence[RiskLevel]]
            Risk level filter.

        risk_type : typing.Optional[typing.Sequence[str]]
            Risk type filter.

        enabled : typing.Optional[bool]
            Risk enabled filter.

        visible : typing.Optional[bool]
            Risk visible filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyRiskFactorsResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_risk_factors(
            id=["psa_owner_of_ofac_fto_sanctioned"],
            risk_category=["sanctions"],
            level=["high"],
            risk_type=["network"],
            enabled=True,
            visible=True,
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/risk_factors",
            method="GET",
            params={
                "id": id,
                "risk_category": risk_category,
                "level": level,
                "risk_type": risk_type,
                "enabled": enabled,
                "visible": visible,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyRiskFactorsResponse,
                    parse_obj_as(
                        type_=GetOntologyRiskFactorsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_sources(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        country: typing.Optional[typing.Sequence[Country]] = None,
        source_type: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologySourcesResponse:
        """
        Get sources from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Source Id filter.

        country : typing.Optional[typing.Sequence[Country]]
            Source country filter.

        source_type : typing.Optional[typing.Sequence[str]]
            Source type filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologySourcesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_sources(
            id=["e85d865943ee6d8369307569d2ad9de0"],
            country=["XXX"],
            source_type=["adverse_media_/_negative_news_data"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/sources",
            method="GET",
            params={
                "id": id,
                "country": country,
                "source_type": source_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologySourcesResponse,
                    parse_obj_as(
                        type_=GetOntologySourcesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_source_types(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologySourceTypesResponse:
        """
        Get source types from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Source type Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologySourceTypesResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.ontology.get_source_types(
            id=["adverse_media_/_negative_news_data"],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/ontology/source_types",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologySourceTypesResponse,
                    parse_obj_as(
                        type_=GetOntologySourceTypesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncOntologyClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_ontology(self, *, request_options: typing.Optional[RequestOptions] = None) -> GetOntologyResponse:
        """
        Get ontology data for all resource types.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_ontology()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyResponse,
                    parse_obj_as(
                        type_=GetOntologyResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_attributes(
        self,
        *,
        id: typing.Optional[typing.Sequence[Attributes]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyAttributesResponse:
        """
        Get attributes from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Attributes]]
            Attribute Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyAttributesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_attributes(
                id=["additional_information"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/attributes",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyAttributesResponse,
                    parse_obj_as(
                        type_=GetOntologyAttributesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_countries(
        self,
        *,
        id: typing.Optional[typing.Sequence[Country]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyCountriesResponse:
        """
        Get countries from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Country]]
            Country Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyCountriesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_countries(
                id=["USA"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/countries",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyCountriesResponse,
                    parse_obj_as(
                        type_=GetOntologyCountriesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_currencies(
        self,
        *,
        id: typing.Optional[typing.Sequence[Currency]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyCurrenciesResponse:
        """
        Get currencies from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Currency]]
            Currency Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyCurrenciesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_currencies(
                id=["USD"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/currencies",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyCurrenciesResponse,
                    parse_obj_as(
                        type_=GetOntologyCurrenciesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_entity_types(
        self,
        *,
        id: typing.Optional[typing.Sequence[Entities]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyEntityTypesResponse:
        """
        Get entity types from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Entities]]
            Entity type Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyEntityTypesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_entity_types(
                id=["aircraft"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/entity_types",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyEntityTypesResponse,
                    parse_obj_as(
                        type_=GetOntologyEntityTypesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_enums(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyEnumsResponse:
        """
        Get enums from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Enum Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyEnumsResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_enums(
                id=["address_type"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/enums",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyEnumsResponse,
                    parse_obj_as(
                        type_=GetOntologyEnumsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_hs_codes(
        self,
        *,
        code: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyHsCodesResponse:
        """
        Get HS codes from ontology data.

        Parameters
        ----------
        code : typing.Optional[typing.Sequence[str]]
            HS code filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyHsCodesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_hs_codes(
                code=["1503"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/hs_codes",
            method="GET",
            params={
                "code": code,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyHsCodesResponse,
                    parse_obj_as(
                        type_=GetOntologyHsCodesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_identifiers(
        self,
        *,
        id: typing.Optional[typing.Sequence[IdentifierType]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyIdentifiersResponse:
        """
        Get identifiers from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[IdentifierType]]
            Identifier Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyIdentifiersResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_identifiers(
                id=["aer_free_zone_license"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/identifiers",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyIdentifiersResponse,
                    parse_obj_as(
                        type_=GetOntologyIdentifiersResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_languages(
        self,
        *,
        id: typing.Optional[typing.Sequence[Language]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyLanguagesResponse:
        """
        Get languages from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Language]]
            Language Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyLanguagesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_languages(
                id=["en"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/languages",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyLanguagesResponse,
                    parse_obj_as(
                        type_=GetOntologyLanguagesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_regions(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyRegionsResponse:
        """
        Get regions from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Region Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyRegionsResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_regions(
                id=["usa_&_canada"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/regions",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyRegionsResponse,
                    parse_obj_as(
                        type_=GetOntologyRegionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_relationships(
        self,
        *,
        id: typing.Optional[typing.Sequence[Relationships]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyRelationshipsResponse:
        """
        Get relationships from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Relationships]]
            Relationship Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyRelationshipsResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_relationships(
                id=["auditor_of"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/relationships",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyRelationshipsResponse,
                    parse_obj_as(
                        type_=GetOntologyRelationshipsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_risk_factors(
        self,
        *,
        id: typing.Optional[typing.Sequence[Risk]] = None,
        risk_category: typing.Optional[typing.Sequence[RiskCategory]] = None,
        level: typing.Optional[typing.Sequence[RiskLevel]] = None,
        risk_type: typing.Optional[typing.Sequence[str]] = None,
        enabled: typing.Optional[bool] = None,
        visible: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologyRiskFactorsResponse:
        """
        Get risk factors from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[Risk]]
            Risk factor Id filter.

        risk_category : typing.Optional[typing.Sequence[RiskCategory]]
            Risk category filter.

        level : typing.Optional[typing.Sequence[RiskLevel]]
            Risk level filter.

        risk_type : typing.Optional[typing.Sequence[str]]
            Risk type filter.

        enabled : typing.Optional[bool]
            Risk enabled filter.

        visible : typing.Optional[bool]
            Risk visible filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologyRiskFactorsResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_risk_factors(
                id=["psa_owner_of_ofac_fto_sanctioned"],
                risk_category=["sanctions"],
                level=["high"],
                risk_type=["network"],
                enabled=True,
                visible=True,
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/risk_factors",
            method="GET",
            params={
                "id": id,
                "risk_category": risk_category,
                "level": level,
                "risk_type": risk_type,
                "enabled": enabled,
                "visible": visible,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologyRiskFactorsResponse,
                    parse_obj_as(
                        type_=GetOntologyRiskFactorsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_sources(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        country: typing.Optional[typing.Sequence[Country]] = None,
        source_type: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologySourcesResponse:
        """
        Get sources from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Source Id filter.

        country : typing.Optional[typing.Sequence[Country]]
            Source country filter.

        source_type : typing.Optional[typing.Sequence[str]]
            Source type filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologySourcesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_sources(
                id=["e85d865943ee6d8369307569d2ad9de0"],
                country=["XXX"],
                source_type=["adverse_media_/_negative_news_data"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/sources",
            method="GET",
            params={
                "id": id,
                "country": country,
                "source_type": source_type,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologySourcesResponse,
                    parse_obj_as(
                        type_=GetOntologySourcesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_source_types(
        self,
        *,
        id: typing.Optional[typing.Sequence[str]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOntologySourceTypesResponse:
        """
        Get source types from ontology data.

        Parameters
        ----------
        id : typing.Optional[typing.Sequence[str]]
            Source type Id filter.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOntologySourceTypesResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.ontology.get_source_types(
                id=["adverse_media_/_negative_news_data"],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/ontology/source_types",
            method="GET",
            params={
                "id": id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetOntologySourceTypesResponse,
                    parse_obj_as(
                        type_=GetOntologySourceTypesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.risk import Risk
import pydantic
from ...generated_types.types.risk_category import RiskCategory
from ...shared_types.types.risk_level import RiskLevel
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class OntologyRiskFactorsFilters(UniversalBaseModel):
    id: typing.Optional[typing.List[Risk]] = pydantic.Field(default=None)
    """
    Risk factor Id filter.
    """

    risk_category: typing.Optional[typing.List[RiskCategory]] = pydantic.Field(default=None)
    """
    Risk category filter.
    """

    level: typing.Optional[typing.List[RiskLevel]] = pydantic.Field(default=None)
    """
    Risk level filter.
    """

    risk_type: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Risk type filter.
    """

    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Risk enabled filter.
    """

    visible: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Risk visible filter.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .coordinates import Coordinates
from .entity_search_response import EntitySearchResponse
from .filter_list import FilterList
from .record_search_response import RecordSearchResponse
from .risk_factor import RiskFactor
from .search_results import SearchResults
from .source_id import SourceId

__all__ = [
    "Coordinates",
    "EntitySearchResponse",
    "FilterList",
    "RecordSearchResponse",
    "RiskFactor",
    "SearchResults",
    "SourceId",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .share_information import ShareInformation
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntityRiskSummaryNetworkPath(UniversalBaseModel):
    sayari_entity_id: str
    sayari_entity_label: str
    relationship_type: str
    relationship_status: str
    former: bool
    first_observed: str
    last_observed: str
    start_date: typing.Optional[str] = None
    shares: typing.Optional[ShareInformation] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.entities import Entities
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class OntologyEntityTypesFilters(UniversalBaseModel):
    id: typing.Optional[typing.List[Entities]] = pydantic.Field(default=None)
    """
    Entity type Id filter.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_hs_codes_filters import OntologyHsCodesFilters
import typing
from .ontology_hs_code import OntologyHsCode
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyHsCodesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyHsCodesResponse,
        OntologyHsCode,
        OntologyHsCodesFilters,
    )

    GetOntologyHsCodesResponse(
        filters=OntologyHsCodesFilters(
            code=["1503"],
        ),
        data=[
            OntologyHsCode(
                code="1503",
                short_description="Lard & tallow products",
                long_description="Lard stearin, lard oil, oleostearin, oleo-oil and tallow oil; not emulsified or mixed or otherwise prepared",
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyHsCodesFilters
    data: typing.List[OntologyHsCode]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .create_project_entity_attribute_response_data import CreateProjectEntityAttributeResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class CreateProjectEntityAttributeResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_attributes import (
        CreateProjectEntityAttributeResponse,
        CreateProjectEntityAttributeResponseData,
    )

    CreateProjectEntityAttributeResponse(
        data=CreateProjectEntityAttributeResponseData(
            id="nK9mP2",
            field="custom_phone",
            value="+1-555-123-4567",
            match_resolution=False,
        ),
    )
    """

    data: CreateProjectEntityAttributeResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .string_or_number import StringOrNumber
from ...generated_types.types.country import Country
from ...generated_types.types.entities import Entities
from .resolution_profile import ResolutionProfile
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class CreateResolvedProjectEntityRequest(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity import CreateResolvedProjectEntityRequest

    CreateResolvedProjectEntityRequest(
        name=["VTB Bank"],
        country=["RUS"],
        address=["Moscow"],
        identifier=["253400V1H6ART1UQ0N98"],
        profile="corporate",
    )
    """

    identifier: typing.Optional[typing.List[StringOrNumber]] = None
    name: typing.Optional[typing.List[str]] = None
    country: typing.Optional[typing.List[Country]] = None
    address: typing.Optional[typing.List[str]] = None
    date_of_birth: typing.Optional[typing.List[str]] = None
    contact: typing.Optional[typing.List[StringOrNumber]] = None
    type: typing.Optional[typing.List[Entities]] = None
    city: typing.Optional[typing.List[str]] = None
    state: typing.Optional[typing.List[str]] = None
    profile: typing.Optional[ResolutionProfile] = None
    enable_llm_clean: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to enable LLM-based data cleaning to remove noise and standardize entity attributes. Defaults to true if not supplied. Set to false to disable LLM cleaning.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .trade_traversal_path import TradeTraversalPath
from .trade_traversal_entity import TradeTraversalEntity
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TradeTraversalData(UniversalBaseModel):
    paths: typing.List[TradeTraversalPath]
    entities: typing.Dict[str, TradeTraversalEntity]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_base_filters import OntologyBaseFilters
import typing
from .ontology_enum import OntologyEnum
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyEnumsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyEnumsResponse,
        OntologyBaseFilters,
        OntologyEnum,
        OntologyEnumSymbol,
    )

    GetOntologyEnumsResponse(
        filters=OntologyBaseFilters(
            id=["address_type"],
        ),
        data=[
            OntologyEnum(
                id="address_type",
                label="Address Type",
                comment="This enumerated type indicates the kind of location an address is referring to.",
                symbols=[
                    OntologyEnumSymbol(
                        id="arrival",
                        label="Arrival",
                        comment="This enumerated type indicates the kind of location an address is referring to.",
                    )
                ],
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyBaseFilters
    data: typing.List[OntologyEnum]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .trade_traversal_component import TradeTraversalComponent
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TradeTraversalPathSegment(UniversalBaseModel):
    tier: int = pydantic.Field()
    """
    Associated tier for that path segment (1-5)
    """

    entity_id: str = pydantic.Field()
    """
    Supplier entity ID
    """

    components: typing.List[TradeTraversalComponent] = pydantic.Field()
    """
    Components shipped by the supplier
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...generated_types.types.relationships import Relationships
import typing
from .ontology_relationship_between import OntologyRelationshipBetween
from ...generated_types.types.attributes import Attributes
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class OntologyRelationship(UniversalBaseModel):
    id: Relationships
    label: str
    description: str
    comment: str
    type: str
    inverse: Relationships
    between: typing.List[OntologyRelationshipBetween]
    attributes: typing.List[Attributes]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ReportingPeriodType = typing.Union[
    typing.Literal[
        "annual_fiscal", "last_twelve_months", "quarterly_fiscal", "semi_annual_fiscal", "year_to_date_fiscal"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from .create_project_entity_attribute_request import CreateProjectEntityAttributeRequest
from .create_project_entity_attribute_response import CreateProjectEntityAttributeResponse
from .create_project_entity_attribute_response_data import CreateProjectEntityAttributeResponseData
from .project_entity_attribute import ProjectEntityAttribute
from .project_entity_attribute_value import ProjectEntityAttributeValue
from .project_entity_attributes_response import ProjectEntityAttributesResponse
from .update_project_entity_attribute_request import UpdateProjectEntityAttributeRequest
from .update_project_entity_attribute_response import UpdateProjectEntityAttributeResponse
from .update_project_entity_attribute_response_data import UpdateProjectEntityAttributeResponseData

__all__ = [
    "CreateProjectEntityAttributeRequest",
    "CreateProjectEntityAttributeResponse",
    "CreateProjectEntityAttributeResponseData",
    "ProjectEntityAttribute",
    "ProjectEntityAttributeValue",
    "ProjectEntityAttributesResponse",
    "UpdateProjectEntityAttributeRequest",
    "UpdateProjectEntityAttributeResponse",
    "UpdateProjectEntityAttributeResponseData",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_base_filters import OntologyBaseFilters
import typing
from .ontology_source_type import OntologySourceType
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologySourceTypesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologySourceTypesResponse,
        OntologyBaseFilters,
        OntologySourceType,
    )

    GetOntologySourceTypesResponse(
        filters=OntologyBaseFilters(
            id=["adverse_media_/_negative_news_data"],
        ),
        data=[
            OntologySourceType(
                id="adverse_media_/_negative_news_data",
                label="Adverse Media / Negative News Data",
            )
        ],
        total_count=1,
    )
    """

    filters: OntologyBaseFilters
    data: typing.List[OntologySourceType]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .project_entity_risk_summary_data import ProjectEntityRiskSummaryData
from .project_entity_risk_summary_response_filters import ProjectEntityRiskSummaryResponseFilters
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ProjectEntityRiskSummaryResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity import (
        ProjectEntityRiskSummaryData,
        ProjectEntityRiskSummaryNetworkPath,
        ProjectEntityRiskSummaryResponse,
        ProjectEntityRiskSummaryResponseFilters,
        ProjectEntityRiskSummaryRiskFactor,
        ProjectRiskCategory,
        ShareInformation,
    )

    ProjectEntityRiskSummaryResponse(
        data=ProjectEntityRiskSummaryData(
            project_entity_id="GleDrP",
            project_id="8YMJNG",
            risk_factors=[
                ProjectEntityRiskSummaryRiskFactor(
                    id="imports_ilab_child_labor",
                    label="Imports Goods with ILAB Child Labor Risk",
                    value="true",
                    level="elevated",
                    source_entity_ids=["FFgmjk4bK6vDn25yMypciw"],
                    metadata=[
                        {
                            "traversal_path": [
                                "FFgmjk4bK6vDn25yMypciw|receiver_of|QB7r598_7sPrCNefvZrAyw"
                            ],
                            "origin_shipment_product": [
                                "640299",
                                "5705",
                                "62",
                                "5702",
                                "64",
                                "42",
                            ],
                        }
                    ],
                    risk_intelligence=[
                        {
                            "type": "financial_risk_score",
                            "score": 36,
                            "Label": "S&P RiskGauge Credit Risk",
                        }
                    ],
                    risk_categories=[
                        ProjectRiskCategory(
                            id="forced_labor",
                            label="Forced labor",
                            risk_factors=["imports_ilab_child_labor"],
                        )
                    ],
                    network_paths=[[]],
                ),
                ProjectEntityRiskSummaryRiskFactor(
                    id="forced_labor_xinjiang_origin_subtier",
                    label="Supplier Network with Xinjiang-Based Entity",
                    value=2,
                    level="elevated",
                    source_entity_ids=["FFgmjk4bK6vDn25yMypciw"],
                    metadata=[
                        {
                            "traversal_path": [
                                "FFgmjk4bK6vDn25yMypciw|receives_from|doWJaXqr57DBYPyHcF_BxQ|receives_from|A3YwnnynaDQnlinlbt-UlQ"
                            ]
                        }
                    ],
                    risk_intelligence=[
                        {
                            "type": "financial_risk_score",
                            "score": 36,
                            "Label": "S&P RiskGauge Credit Risk",
                        }
                    ],
                    risk_categories=[
                        ProjectRiskCategory(
                            id="forced_labor",
                            label="Forced labor",
                            risk_factors=["forced_labor_xinjiang_origin_subtier"],
                        )
                    ],
                    network_paths=[
                        [
                            ProjectEntityRiskSummaryNetworkPath(
                                sayari_entity_id="doWJaXqr57DBYPyHcF_BxQ",
                                sayari_entity_label="LIBERTY MILLS LIMITED",
                                relationship_type="receives_from",
                                relationship_status="active",
                                former=False,
                                first_observed="2024-03-08",
                                last_observed="2024-03-14",
                                start_date="2024-03-08",
                                shares=ShareInformation(),
                            ),
                            ProjectEntityRiskSummaryNetworkPath(
                                sayari_entity_id="A3YwnnynaDQnlinlbt-UlQ",
                                sayari_entity_label="XINXIANG CHEMICAL FIBRE CO., LTD",
                                relationship_type="receives_from",
                                relationship_status="active",
                                former=False,
                                first_observed="2024-03-11",
                                last_observed="2024-03-25",
                                start_date="2024-03-11",
                                shares=ShareInformation(),
                            ),
                        ]
                    ],
                ),
                ProjectEntityRiskSummaryRiskFactor(
                    id="forced_labor_sheffield_hallam_university_reports_origin_subtier",
                    label="Supplier Network with Entity from Sheffield Hallam University Forced Labor Reports",
                    value=2,
                    level="elevated",
                    source_entity_ids=["FFgmjk4bK6vDn25yMypciw"],
                    metadata=[
                        {
                            "traversal_path": [
                                "FFgmjk4bK6vDn25yMypciw|receives_from|hky4niXTOuJOZ3YJUHBvpw|receives_from|jcG2-gcTVXhH6J2UO7bASg"
                            ]
                        }
                    ],
                    risk_intelligence=[
                        {
                            "type": "financial_risk_score",
                            "score": 36,
                            "Label": "S&P RiskGauge Credit Risk",
                        }
                    ],
                    risk_categories=[
                        ProjectRiskCategory(
                            id="forced_labor",
                            label="Forced labor",
                            risk_factors=[
                                "forced_labor_sheffield_hallam_university_reports_origin_subtier"
                            ],
                        )
                    ],
                    network_paths=[
                        [
                            ProjectEntityRiskSummaryNetworkPath(
                                sayari_entity_id="hky4niXTOuJOZ3YJUHBvpw",
                                sayari_entity_label="KOHINOOR TEXTILE MILLS LIMITED",
                                relationship_type="receives_from",
                                relationship_status="active",
                                former=False,
                                first_observed="2023-09-27",
                                last_observed="2023-09-27",
                                start_date="2023-09-27",
                                shares=ShareInformation(),
                            ),
                            ProjectEntityRiskSummaryNetworkPath(
                                sayari_entity_id="jcG2-gcTVXhH6J2UO7bASg",
                                sayari_entity_label="WEIQIAO TEXTILE COMPANY LIMITED",
                                relationship_type="receives_from",
                                relationship_status="active",
                                former=False,
                                first_observed="2017-03-08",
                                last_observed="2025-04-21",
                                start_date="2017-03-08",
                                shares=ShareInformation(),
                            ),
                        ]
                    ],
                ),
                ProjectEntityRiskSummaryRiskFactor(
                    id="forced_labor_uflpa_origin_subtier",
                    label="Supplier Network with UFLPA Entity",
                    value=3,
                    level="elevated",
                    source_entity_ids=["FFgmjk4bK6vDn25yMypciw"],
                    metadata=[
                        {
                            "traversal_path": [
                                "FFgmjk4bK6vDn25yMypciw|receives_from|Lg1BHckRWGrKUT03LUy3iw|receives_from|rmgKmpNeQxhVNnrnemI2yQ|receives_from|CZAZypVNS-jkOGzpRpCXEw"
                            ]
                        }
                    ],
                    risk_intelligence=[
                        {
                            "type": "financial_risk_score",
                            "score": 36,
                            "Label": "S&P RiskGauge Credit Risk",
                        }
                    ],
                    risk_categories=[
                        ProjectRiskCategory(
                            id="forced_labor",
                            label="Forced labor",
                            risk_factors=["forced_labor_uflpa_origin_subtier"],
                        )
                    ],
                    network_paths=[
                        [
                            ProjectEntityRiskSummaryNetworkPath(
                                sayari_entity_id="Lg1BHckRWGrKUT03LUy3iw",
                                sayari_entity_label="KAMAL LIMITED",
                                relationship_type="receives_from",
                                relationship_status="active",
                                former=False,
                                first_observed="2024-04-29",
                                last_observed="2025-04-21",
                                start_date="2024-04-29",
                                shares=ShareInformation(),
                            ),
                            ProjectEntityRiskSummaryNetworkPath(
                                sayari_entity_id="rmgKmpNeQxhVNnrnemI2yQ",
                                sayari_entity_label="CôNG TY TRáCH NHIệM HữU HạN HYOSUNG ĐồNG NAI",
                                relationship_type="receives_from",
                                relationship_status="active",
                                former=False,
                                first_observed="2023-09-28",
                                last_observed="2025-04-13",
                                start_date="2023-09-28",
                                shares=ShareInformation(),
                            ),
                            ProjectEntityRiskSummaryNetworkPath(
                                sayari_entity_id="CZAZypVNS-jkOGzpRpCXEw",
                                sayari_entity_label="HANGZHOU UNION BIOTECHNOLOGY CO., LTD",
                                relationship_type="receives_from",
                                relationship_status="active",
                                former=False,
                                first_observed="2023-03-09",
                                last_observed="2025-02-27",
                                start_date="2023-03-09",
                                shares=ShareInformation(),
                            ),
                        ]
                    ],
                ),
            ],
        ),
        filters=ProjectEntityRiskSummaryResponseFilters(
            risk_factor=[
                "imports_ilab_child_labor",
                "forced_labor_xinjiang_origin_subtier",
            ],
            risk_category=["forced_labor"],
        ),
    )
    """

    data: ProjectEntityRiskSummaryData
    filters: ProjectEntityRiskSummaryResponseFilters

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .trade_traversal_filters import TradeTraversalFilters
from .trade_traversal_data import TradeTraversalData
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class UpstreamTradeTraversalResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.supply_chain import (
        TradeTraversalComponent,
        TradeTraversalData,
        TradeTraversalEntity,
        TradeTraversalFilters,
        TradeTraversalPath,
        TradeTraversalPathSegment,
        UpstreamTradeTraversalResponse,
    )

    UpstreamTradeTraversalResponse(
        filters=TradeTraversalFilters(
            product=["7616"],
        ),
        data=TradeTraversalData(
            paths=[
                TradeTraversalPath(
                    source_entity_id="aGhVqFtVmSjbXqH6oBX6IA",
                    path=[
                        TradeTraversalPathSegment(
                            tier=2,
                            entity_id="Tdge30S7idW8cJHRaTABtg",
                            components=[
                                TradeTraversalComponent(
                                    hs_code="2818",
                                    arrival_countries=["VNM"],
                                    departure_countries=["TWN"],
                                    max_date="2023-03-01",
                                )
                            ],
                        )
                    ],
                ),
                TradeTraversalPath(
                    source_entity_id="aGhVqFtVmSjbXqH6oBX6IA",
                    path=[
                        TradeTraversalPathSegment(
                            tier=2,
                            entity_id="s7rRJAvSAW8YWuGPGzDb_w",
                            components=[
                                TradeTraversalComponent(
                                    hs_code="7609",
                                    arrival_countries=["VNM"],
                                    departure_countries=["CHN"],
                                    max_date="2023-06-01",
                                )
                            ],
                        )
                    ],
                ),
                TradeTraversalPath(
                    source_entity_id="aGhVqFtVmSjbXqH6oBX6IA",
                    path=[
                        TradeTraversalPathSegment(
                            tier=2,
                            entity_id="9QIh3SU3TDipp80ibWMYfg",
                            components=[
                                TradeTraversalComponent(
                                    hs_code="7616",
                                    arrival_countries=["VNM"],
                                    departure_countries=["TWN"],
                                    max_date="2023-12-01",
                                )
                            ],
                        )
                    ],
                ),
                TradeTraversalPath(
                    source_entity_id="aGhVqFtVmSjbXqH6oBX6IA",
                    path=[
                        TradeTraversalPathSegment(
                            tier=2,
                            entity_id="s7rRJAvSAW8YWuGPGzDb_w",
                            components=[
                                TradeTraversalComponent(
                                    hs_code="7616",
                                    arrival_countries=["VNM"],
                                    departure_countries=["CHN"],
                                    max_date="2023-06-01",
                                )
                            ],
                        )
                    ],
                ),
            ],
            entities={
                "9QIh3SU3TDipp80ibWMYfg": TradeTraversalEntity(
                    id="9QIh3SU3TDipp80ibWMYfg",
                    type="company",
                    label="ZITAI PRECISION MACHINERY CO LTD",
                    risk_factors=[],
                    countries=["BRA", "CHN", "DEU", "GBR", "JPN", "MEX", "TWN"],
                ),
                "s7rRJAvSAW8YWuGPGzDb_w": TradeTraversalEntity(
                    id="s7rRJAvSAW8YWuGPGzDb_w",
                    type="company",
                    label="EQUIPMENT AND MACHINE CO LTD",
                    risk_factors=[
                        "exports_ilab_forced_labor",
                        "psa_imports_ilab_forced_labor",
                        "psa_exports_ilab_child_labor",
                        "exports_ilab_child_labor",
                        "psa_exports_ilab_forced_labor",
                        "imports_ilab_forced_labor",
                    ],
                    countries=[
                        "AUS",
                        "BLZ",
                        "CHE",
                        "CHN",
                        "CZE",
                        "DEU",
                        "DNK",
                        "GBR",
                        "HKG",
                        "ISR",
                        "ITA",
                        "JPN",
                        "KOR",
                        "MYS",
                        "NLD",
                        "POL",
                        "ROU",
                        "SGP",
                        "TWN",
                        "USA",
                    ],
                ),
                "Tdge30S7idW8cJHRaTABtg": TradeTraversalEntity(
                    id="Tdge30S7idW8cJHRaTABtg",
                    type="company",
                    label="TIEN YEOU TRADING CO LTD",
                    risk_factors=[],
                    countries=["ITA", "TWN"],
                ),
                "aGhVqFtVmSjbXqH6oBX6IA": TradeTraversalEntity(
                    id="aGhVqFtVmSjbXqH6oBX6IA",
                    type="company",
                    label="Công ty TNHH KRICO",
                    risk_factors=[],
                    countries=["VNM"],
                ),
            },
        ),
        explored_count=98,
        partial_results=False,
    )
    """

    status: typing.Optional[int] = None
    success: typing.Optional[bool] = None
    message: typing.Optional[str] = None
    filters: TradeTraversalFilters
    data: TradeTraversalData
    explored_count: int = pydantic.Field()
    """
    Number of hops explored in the traversal
    """

    partial_results: bool = pydantic.Field()
    """
    True if the traversal returned partial results
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .trade_traversal_component import TradeTraversalComponent
from .trade_traversal_data import TradeTraversalData
from .trade_traversal_entity import TradeTraversalEntity
from .trade_traversal_filters import TradeTraversalFilters
from .trade_traversal_path import TradeTraversalPath
from .trade_traversal_path_segment import TradeTraversalPathSegment
from .upstream_trade_traversal_response import UpstreamTradeTraversalResponse

__all__ = [
    "TradeTraversalComponent",
    "TradeTraversalData",
    "TradeTraversalEntity",
    "TradeTraversalFilters",
    "TradeTraversalPath",
    "TradeTraversalPathSegment",
    "UpstreamTradeTraversalResponse",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_attributes_filters import OntologyAttributesFilters
import typing
from .ontology_attribute import OntologyAttribute
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyAttributesResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyAttributesResponse,
        OntologyAttribute,
        OntologyAttributeField,
        OntologyAttributesFilters,
    )

    GetOntologyAttributesResponse(
        filters=OntologyAttributesFilters(
            id=["additional_information"],
        ),
        data=[
            OntologyAttribute(
                id="additional_information",
                label="Additional Information",
                comment="This is a generic attribute used to hold miscellaneous information not covered by any other attribute.",
                fields=[
                    OntologyAttributeField(
                        id="value",
                        label="Value",
                        comment="The additional information itself",
                        type=["null", "string"],
                    )
                ],
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyAttributesFilters
    data: typing.List[OntologyAttribute]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .currency import Currency
from .reporting_period_type import ReportingPeriodType
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class FinancialsProperties(UniversalBaseModel):
    accounts_payable: typing.Optional[float] = pydantic.Field(default=None)
    """
    Trade payables for the purchase of materials and supplies to be used in the production of goods or in providing of services and are due in customary trade terms within one year or within the normal operating cycle of the company.
    """

    asset_writeoff: typing.Optional[float] = pydantic.Field(default=None)
    """
    Write-off of any intangible or tangible fixed assets by the company and includes any value charged towards restructuring of operations.
    """

    assets: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total value of assets owned by a company
    """

    basic_eps: typing.Optional[float] = pydantic.Field(default=None)
    """
    Profitability metric that indicates how much profit a company generates for each outstanding share of common stock.
    """

    cash_and_equivalent: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total Cash and Equivalent
    """

    cash_financing: typing.Optional[float] = pydantic.Field(default=None)
    """
    Net cash used or generated in financing activities, during the stated period of time.
    """

    cash_investing: typing.Optional[float] = pydantic.Field(default=None)
    """
    Net cash used or generated in investing activities, during the stated period of time.
    """

    cash_operations: typing.Optional[float] = pydantic.Field(default=None)
    """
    Net cash used or generated in operating activities, during the stated period of time.
    """

    change_accounts_payable: typing.Optional[float] = pydantic.Field(default=None)
    """
    Increase or decrease in accounts payable by the company during the stated period.
    """

    change_accounts_receivable: typing.Optional[float] = pydantic.Field(default=None)
    """
    Increase or decrease in the accounts receivable of the company during the stated period.
    """

    change_inventory: typing.Optional[float] = pydantic.Field(default=None)
    """
    Change in the inventory of the company reflected in the operating section of cash flow statement.
    """

    common_stock: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total Common Stock
    """

    currency: typing.Optional[Currency] = pydantic.Field(default=None)
    """
    Reporting currency
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    as-of date of attribute
    """

    employees: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total employees
    """

    extra: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    extra information of attribute
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    start date of attribute
    """

    gross_profit: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total Gross Profit
    """

    interest_expense: typing.Optional[float] = pydantic.Field(default=None)
    """
    Interest expense (net of capitalized interest) incurred by the company on the debt taken. Also includes debt procurement costs, and dividend paid by parent company on the preferred stock of its subsidiary or on trust preferred securities reported in the income statement.
    """

    inventory: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total Inventory
    """

    issued_common_stock: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total cash inflow received from issuing new common shares during the reporting period.
    """

    legal_settlements: typing.Optional[float] = pydantic.Field(default=None)
    """
    Costs incurred in legal disputes or receipts from legal settlements received by the company and reflected on the income statement.
    """

    liabilities: typing.Optional[float] = pydantic.Field(default=None)
    """
    Sum of the combined debts a company owes
    """

    net_change_cash: typing.Optional[float] = pydantic.Field(default=None)
    """
    Net increase or decrease in cash and cash equivalents during the stated period of time. Sum of cash flows from operating activities, investing activities and financing activities plus foreign exchange rate adjustments and other miscellaneous cash flows.
    """

    net_income: typing.Optional[float] = pydantic.Field(default=None)
    """
    Company's earnings for a period after subtracting operating costs, taxes, and interest
    """

    operating_income: typing.Optional[float] = pydantic.Field(default=None)
    """
    Reported Operating Income
    """

    paid_up_capital: typing.Optional[float] = pydantic.Field(default=None)
    """
    Paid-up capital is the capital already held by the company
    """

    rd_expenses: typing.Optional[float] = pydantic.Field(default=None)
    """
    Costs incurred by a company on the development of a new product, innovation relating to technology formulation, process development, or on the process undertaken in upgrading the existing product or service line.
    """

    registered_capital: typing.Optional[float] = pydantic.Field(default=None)
    """
    Registered capital is the maximum amount of share capital that a company is authorized to raise
    """

    reporting_period_type: typing.Optional[ReportingPeriodType] = pydantic.Field(default=None)
    """
    Reporting period type
    """

    revenue: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total amount of income generated by the sale of goods or services related to the company's primary operations
    """

    sale_ppe: typing.Optional[float] = pydantic.Field(default=None)
    """
    Cash flows obtained by the company through the sale of property, plant, and equipment.
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    end date of attribute
    """

    total_capitalization: typing.Optional[float] = pydantic.Field(default=None)
    """
    The sum of total debt and all types of equity of a company.
    """

    total_current_assets: typing.Optional[float] = pydantic.Field(default=None)
    """
    Assets which are expected to be converted into cash or used in the production of revenue within a period of twelve months.
    """

    total_current_liabilities: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total amount of a company’s short-term financial obligations that are due within one year, such as accounts payable, short-term loans, and wages payable
    """

    total_debt: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total Debt
    """

    total_debt_issued: typing.Optional[float] = pydantic.Field(default=None)
    """
    Cash inflow from issuance of debt.
    """

    total_dividends: typing.Optional[float] = pydantic.Field(default=None)
    """
    Cash outflows towards dividends or distributions, either to common or preferred stockholders during the relevant period. The value paid may relate to pending dividend of earlier period also.
    """

    total_equity: typing.Optional[float] = pydantic.Field(default=None)
    """
    Equity as defined under the indicated accounting principles. Includes par value, paid in capital, retained earnings, and other adjustments to equity.
    """

    total_liabilities: typing.Optional[float] = pydantic.Field(default=None)
    """
    All liabilities (current and long-term) as of the date indicated, as carried on the balance sheet.
    """

    total_operating_expenses: typing.Optional[float] = pydantic.Field(default=None)
    """
    The costs a business incurs to maintain its day-to-day operations, excluding the cost of goods sold.
    """

    total_receivables: typing.Optional[float] = pydantic.Field(default=None)
    """
    Summation of accounts receivable - trade, accounts receivable - other, and loans receivable current.
    """

    unusual_items: typing.Optional[float] = pydantic.Field(default=None)
    """
    Sum of all income or expenses that are deemed infrequent and not typical of a company's ordinary operations.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .get_ontology_attributes_response import GetOntologyAttributesResponse
from .get_ontology_countries_response import GetOntologyCountriesResponse
from .get_ontology_currencies_response import GetOntologyCurrenciesResponse
from .get_ontology_entity_types_response import GetOntologyEntityTypesResponse
from .get_ontology_enums_response import GetOntologyEnumsResponse
from .get_ontology_hs_codes_response import GetOntologyHsCodesResponse
from .get_ontology_identifiers_response import GetOntologyIdentifiersResponse
from .get_ontology_languages_response import GetOntologyLanguagesResponse
from .get_ontology_regions_response import GetOntologyRegionsResponse
from .get_ontology_relationships_response import GetOntologyRelationshipsResponse
from .get_ontology_response import GetOntologyResponse
from .get_ontology_response_data import GetOntologyResponseData
from .get_ontology_risk_factors_response import GetOntologyRiskFactorsResponse
from .get_ontology_source_types_response import GetOntologySourceTypesResponse
from .get_ontology_sources_response import GetOntologySourcesResponse
from .ontology_attribute import OntologyAttribute
from .ontology_attribute_field import OntologyAttributeField
from .ontology_attributes_filters import OntologyAttributesFilters
from .ontology_base_filters import OntologyBaseFilters
from .ontology_countries_filters import OntologyCountriesFilters
from .ontology_country import OntologyCountry
from .ontology_currencies_filters import OntologyCurrenciesFilters
from .ontology_currency import OntologyCurrency
from .ontology_entity_type import OntologyEntityType
from .ontology_entity_type_field import OntologyEntityTypeField
from .ontology_entity_types_filters import OntologyEntityTypesFilters
from .ontology_enum import OntologyEnum
from .ontology_enum_symbol import OntologyEnumSymbol
from .ontology_hs_code import OntologyHsCode
from .ontology_hs_codes_filters import OntologyHsCodesFilters
from .ontology_identifier import OntologyIdentifier
from .ontology_identifiers_filters import OntologyIdentifiersFilters
from .ontology_language import OntologyLanguage
from .ontology_languages_filters import OntologyLanguagesFilters
from .ontology_region import OntologyRegion
from .ontology_relationship import OntologyRelationship
from .ontology_relationship_between import OntologyRelationshipBetween
from .ontology_relationships_filters import OntologyRelationshipsFilters
from .ontology_risk_factor import OntologyRiskFactor
from .ontology_risk_factors_filters import OntologyRiskFactorsFilters
from .ontology_source import OntologySource
from .ontology_source_type import OntologySourceType
from .ontology_sources_filters import OntologySourcesFilters

__all__ = [
    "GetOntologyAttributesResponse",
    "GetOntologyCountriesResponse",
    "GetOntologyCurrenciesResponse",
    "GetOntologyEntityTypesResponse",
    "GetOntologyEnumsResponse",
    "GetOntologyHsCodesResponse",
    "GetOntologyIdentifiersResponse",
    "GetOntologyLanguagesResponse",
    "GetOntologyRegionsResponse",
    "GetOntologyRelationshipsResponse",
    "GetOntologyResponse",
    "GetOntologyResponseData",
    "GetOntologyRiskFactorsResponse",
    "GetOntologySourceTypesResponse",
    "GetOntologySourcesResponse",
    "OntologyAttribute",
    "OntologyAttributeField",
    "OntologyAttributesFilters",
    "OntologyBaseFilters",
    "OntologyCountriesFilters",
    "OntologyCountry",
    "OntologyCurrenciesFilters",
    "OntologyCurrency",
    "OntologyEntityType",
    "OntologyEntityTypeField",
    "OntologyEntityTypesFilters",
    "OntologyEnum",
    "OntologyEnumSymbol",
    "OntologyHsCode",
    "OntologyHsCodesFilters",
    "OntologyIdentifier",
    "OntologyIdentifiersFilters",
    "OntologyLanguage",
    "OntologyLanguagesFilters",
    "OntologyRegion",
    "OntologyRelationship",
    "OntologyRelationshipBetween",
    "OntologyRelationshipsFilters",
    "OntologyRiskFactor",
    "OntologyRiskFactorsFilters",
    "OntologySource",
    "OntologySourceType",
    "OntologySourcesFilters",
]



# This file was auto-generated by Fern from our API Definition.

import typing

Topics = typing.Union[
    typing.Literal[
        "overview",
        "environmental_and_social",
        "cybersecurity",
        "disruption",
        "criminal",
        "reputational",
        "financial",
        "sanctions_and_regulatory",
        "legal",
        "political",
        "terrorism",
    ],
    typing.Any,
]
